@@ -22,16 +22,16 @@
 #ifndef __BC_ZINT_H__
 #define __BC_ZINT_H__
 
-#include "bc.h"
+#include <libglbarcode.h>
 
 G_BEGIN_DECLS
 
-glBarcode *gl_barcode_zint_new (const gchar    *id,
-				      gboolean        text_flag,
-				      gboolean        checksum_flag,
-				      gdouble         w,
-				      gdouble         h,
-				      const gchar    *digits);
+lglBarcode *gl_barcode_zint_new (const gchar    *id,
+                                 gboolean        text_flag,
+                                 gboolean        checksum_flag,
+                                 gdouble         w,
+                                 gdouble         h,
+                                 const gchar    *digits);
 
 G_END_DECLS
 
